# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module OracleFeature
  def self.oracle_running_check
    Puppet.debug 'Feature oracle_running checking availability'
    proc = if Facter.value(:kernel) == 'windows'
             `tasklist | findstr oracle.exe`
           else
             Puppet::Util::Execution.execute('ps -ef | egrep "(ora|xe)_pmon.*$"', :failonfail => false, :combine => true)
           end
    if proc == ''
      Puppet.debug 'Feature oracle_running **NOT** available'
      false
    else
      Puppet.debug 'Feature oracle_running available'
      true
    end
  end

  Puppet.features.add(:oracle_running) do
    oracle_running_check
  end

  Puppet.features.send :meta_def, 'oracle_running?' do
    name = :oracle_running
    final = @results[name]
    @results[name] = OracleFeature.oracle_running_check unless final
    @results[name]
  end
end
