# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
#
# Default features are not rechecked. SO that is why we do the difficult solution.
# Check https://tickets.puppetlabs.com/browse/PUP-5985?jql=text~%22feature%20evaluation%22
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'
# rubocop:disable Style/Documentation
module OracleFeature
  # rubocop:enable Style/Documentation
  def self.oratab_file
    case Facter.value(:osfamily)
    when 'RedHat', 'AIX', 'Suse'
      '/etc/oratab'
    when 'Solaris'
      '/var/opt/oracle/oratab'
    when 'windows'
      "#{Facter.value(:system32)}\\drivers\\etc"
    else
      fail 'error unsupported OS'
    end
  end

  def self.oratab_exists
    Puppet.debug 'Feature oratab_exists checking availability'

    if File.exist?(oratab_file)
      Puppet.debug 'Feature oratab_exists available'
      true
    else
      Puppet.debug 'Feature oratab_exists **NOT** available'
      false
    end
  end

  Puppet.features.add(:oratab_exists) do
    oratab_exists
  end

  Puppet.features.send :meta_def, 'oratab_exists?' do
    name = :oracle11
    final = @results[name]
    @results[name] = OracleFeature.oratab_exists unless final
    @results[name]
  end
end
