#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

newproperty(:size) do
  include EasyType
  include EasyType::Mungers::Size
  include Puppet_X::EnterpriseModules::Oracle::Commands

  desc <<-DESC
    The size of the volume to ensure. .

    This is a required property.

        ora_asm_volume { ...:
          ...
          size => '100M',
        }

  DESC

  # Issue in Puppet causes external types to not always
  # be resolved. Therefore we include the basic variant
  # data_type("Optional[Easy_type::Size]")
  data_type('Optional[Variant[Pattern[/^([0-9]*[k|K|m|M|g|G|t|T])$/], Integer]]')

  on_modify do
    # Because volresize requires a size modifier, we use the K, This means the actual size must be divided by 1024
    k_value = value / 1024
    acfsutil("size #{k_value}K #{provider.mountpath}", :sid => resource.asm_sid)
  end

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('SIZE').to_i * 1024 * 1024
  end
end
