# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:actions, :array_matching => :all) do
  include EasyType
  include EasyType::ArrayProperty

  desc <<-DESC
  With this property, you specificy the actions hat you want to audit
  as part of this policy.  Here is an example on how to use this:

      ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
        ensure   => 'present',
        actions  => ['ALTER DATABASE', 'ALTER SYSTEM', 'CREATE SPFILE'],
      }

  DESC

  def current_value
    value = retrieve
    retrieve == :absent ? [] : value
  end

  def to_drop
    current_value - should
  end

  def to_add
    should - current_value
  end

  on_create do
    "actions #{value.join(',')}"
  end

  data_type('Optional[Array[String[1]]]')

  to_translate_to_resource do |raw_resource|
    value = raw_resource.column_data('ACTIONS')&.split(';')
    value == 'NONE' ? nil : value
  end
end
