# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/mungers'

newparam(:name) do
  include EasyType
  include EasyType::Validators::Name
  include Puppet_X::EnterpriseModules::Oracle::Mungers::LeaveSidRestToUppercase

  desc <<-DESC
    The name of the audit policy including SID.

        ora_audit_policy { 'MY_POL@SID':
          ...
        }

    The SID is optional. When you don't specify an SID, Puppet will take the ASM instance from
    ora_setting with property `default` set to true and use that as the SID. We recomend you to **always** use a full qualified
    name (e.g. a name including the SID) or not do it at all.

  DESC

  isnamevar

  data_type('String[1]')

  to_translate_to_resource do |raw_resource|
    sid = raw_resource.column_data('SID')
    name = raw_resource.column_data('POLICY_NAME')
    "#{name}@#{sid}"
  end
end
