# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:object_actions, :array_matching => :all) do
  include EasyType
  include EasyType::ArrayProperty

  desc <<-DESC
  This resource allows you to manage the Unified Audit policies. This
  Puppet type supports managing the next policy types:

  - privileges
  - roles
  - actions (Anly standard actions)
  - object (only partly)

  Here is an example on how to use this:

      ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
        ensure   => 'present',
        actions  => ['ALTER DATABASE', 'ALTER SYSTEM', 'CREATE SPFILE'],
      }

  DESC

  data_type('Optional[Array[String[1]]]')

  def current_value
    value = retrieve
    retrieve == :absent ? [] : value
  end

  def to_drop
    current_value - should
  end

  def to_add
    should - current_value
  end

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('OBJECT_ACTIONS')&.split(';')&.reject { |e| e == 'NONE' }
  end
end
