# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:object_type) do
  include EasyType

  desc <<-DESC
  This resource allows you to manage the Unified Audit policies. This
  Puppet type supports managing the next policy types:

  - privileges
  - roles
  - actions (Anly standard actions)
  - object (only partly)

  Here is an example on how to use this:

      ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
        ensure   => 'present',
        actions  => ['ALTER DATABASE', 'ALTER SYSTEM', 'CREATE SPFILE'],
      }

  DESC

  data_type('Optional[String[1]]')

  to_translate_to_resource do |raw_resource|
    value = raw_resource.column_data('OBJECT_TYPE')
    value == 'NONE' ? nil : value
  end
end
