# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:privileges, :array_matching => :all) do
  include EasyType
  include EasyType::ArrayProperty

  desc <<-DESC
  With this property, you specificy the privileges hat you want to audit
  as part of this policy.  Here is an example on how to use this:

      ora_audit_policy { 'ORA_DATABASE_PARAMETER@TEST':
        ensure      => 'present',
        privileges  => ['ALTER ANY PROCEDURE', 'ALTER ANY SQL TRANSLATION PROFILE'],
      }

  DESC

  def current_value
    value = retrieve
    retrieve == :absent ? [] : value
  end

  def to_drop
    current_value - should
  end

  def to_add
    should - current_value
  end

  on_create do
    "privileges #{value.join(',')}"
  end

  data_type('Optional[Array[String[1]]]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('PRIVILEGES')&.split(';')
  end
end
