# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:archivelog) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  newvalues(:enabled, :disabled)
  data_type("Optional[Enum['enabled', 'disabled']]")

  desc <<-DESC
    Enable or disable archive log.
  DESC

  to_translate_to_resource do |raw_resource|
    log_mode = raw_resource.column_data('LOG_MODE')
    case log_mode
    when 'ARCHIVELOG'
      'enabled'
    when 'NOARCHIVELOG'
      'disabled'
    end
  end

  on_apply do
    enabled? ? 'archivelog' : 'noarchivelog'
  end

  on_modify do
    sql('alter database flashback off', :sid => instance) if flashback_enabled? && (flashback_should == 'disabled')
    unless arch_is == should
      log_mode = enabled? ? 'archivelog' : 'noarchivelog'
      statement = template('ora_config/ora_database/archivelog.sql.erb', binding)
      sql(statement, :sid => instance)
    end
    sql('alter database flashback on', :sid => instance) if !flashback_enabled? && (flashback_should == 'enabled')
    nil
  end

  def insync?(is)
    return true if resource.contained_by

    super
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end

  def arch_is
    provider.archivelog
  end

  def flashback_enabled?
    provider.flashback == 'enabled'
  end

  def flashback_should
    resource.flashback
  end
end
