#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

require 'puppet_x/enterprisemodules/oracle/schemas'
require 'puppet_x/enterprisemodules/extend_hash'

newparam(:datafiles, :array_matching => :all) do
  # docs
  class ::Puppet::Type::Ora_database::ParameterDatafiles
    include EasyType
    include Puppet_X::EnterpriseModules::Oracle::Schemas
    include Puppet_X::EnterpriseModules::ExtendHash

    desc <<-DESC
    One or more files to be used as datafiles.

    Use this syntax to specify all attributes:

        ora_database{'dbname':
          ...
          datafiles       => [
            {file_name   => 'file1.dbs', size => '10G', reuse => true},
            {file_name   => 'file2.dbs', size => '10G', reuse => true},
          ]
        }

    DESC

    DATAFILES_VALIDATION ||= Puppet_X::EnterpriseModules::Oracle::Schemas::DATAFILE

    def validate(value)
      value = Array[value] unless value.is_a?(Array)
      value.each { |v| ClassyHash.validate_strict(v, DATAFILES_VALIDATION) }
    end

    def value
      "datafile #{datafiles(@value)}" unless @value.empty?
    end
  end
end
