#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

newproperty(:force_logging) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  newvalues(:enabled, :disabled)
  data_type("Optional[Enum['enabled', 'disabled']]")

  desc <<-DESC
    Enable or disable the FORCE LOGGING mode.
  DESC

  to_translate_to_resource do |raw_resource|
    logging = raw_resource.column_data('FORCE_LOGGING')
    case logging
    when 'YES'
      'enabled'
    when 'NO'
      'disabled'
    end
  end

  on_apply do
    enabled? ? 'force_logging' : 'noforce_logging'
  end

  on_modify do
    log_clause = should.to_s == 'enabled' ? 'force logging' : 'no force logging'
    statement = "alter database #{log_clause}"
    sql(statement, :sid => instance)
    nil
  end

  def insync?(is)
    return true unless resource.contained_by.nil?

    super
  end

  private

  def enabled?
    value.to_s == 'enabled'
  end
end
