#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

newproperty(:maxdatafiles, :parent => ::Puppet_X::EnterpriseModules::Oracle::ReadOnlyProperty) do
  include Puppet_X::EnterpriseModules::Oracle::Access
  include EasyType
  include EasyType::Validators::Integer

  desc <<-DESC
    The initial sizing of the datafiles section of the control file.
  DESC

  to_translate_to_resource do |raw_resource|
    if raw_resource['STATE'] == 'running'
      value = sql("SELECT RECORDS_TOTAL FROM v$controlfile_record_section where type = 'DATAFILE'", :sid => raw_resource['SID'])
      value.first['RECORDS_TOTAL']
    end
  end

  on_apply do
    "MAXDATAFILES #{value}"
  end

  data_type('Optional[Integer]')
end
