#
# See the file "LICENSE" for the full license governing this code.
#
# frozen_string_literal: true

newproperty(:maxlogmembers, :parent => ::Puppet_X::EnterpriseModules::Oracle::ReadOnlyProperty) do
  include Puppet_X::EnterpriseModules::Oracle::Access
  include EasyType
  include EasyType::Validators::Integer

  desc <<-DESC
    The maximum number of members, or copies, for a redo log file group.
  DESC

  to_translate_to_resource do |raw_resource|
    if raw_resource['STATE'] == 'running'
      value = sql('SELECT x$kccdi.dimlm MAXLOGMEMBERS FROM sys.x$kccdi', :sid => raw_resource['SID'])
      value.first['RECORDS_TOTAL']
    end
  end

  on_apply do
    "MAXLOGMEMBERS #{value}"
  end

  data_type('Optional[Integer]')
end
