# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
require 'puppet_x/enterprisemodules/oracle/mungers'

newparam(:name) do
  include EasyType
  include EasyType::Validators::Name
  include Puppet_X::EnterpriseModules::Oracle::Settings

  def munge(value)
    scope, parameter_name, for_sid, sid = value.scan(%r{^(.*?/)?(.*?)(:.*?)?(@.*?)?$}).flatten
    begin
      container = sid.nil? ? '' : configuration_value_for(sid[1..-1], 'contained_by')
    rescue Puppet::Error
      container = ''
    end
    for_sid = ':*' if for_sid.nil? && scope.casecmp('SPFILE/').zero?
    for_sid = '' if scope.casecmp('MEMORY/').zero? && for_sid && for_sid[1..-1] == container
    "#{scope.upcase}#{parameter_name.upcase}#{for_sid}#{sid}"
  end

  desc <<-DESC
    The parameter name.
  DESC

  data_type('String[1]')

  isnamevar

  to_translate_to_resource do |raw_resource|
    sid = raw_resource.column_data('SID')
    for_sid = raw_resource.column_data('FOR_SID')
    parameter_name = raw_resource.column_data('NAME').upcase
    container = configuration_value_for(sid, 'contained_by')
    scope = raw_resource.column_data('SCOPE').upcase
    if (sid == for_sid || container == for_sid) && scope == 'MEMORY'
      "#{scope}/#{parameter_name}@#{sid}"
    else
      "#{scope}/#{parameter_name}:#{for_sid}@#{sid}"
    end
  end
end
