# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../.."))
$LOAD_PATH.unshift(File.absolute_path("#{__dir__}/../../../../easy_type/lib"))
require 'easy_type'

Puppet::Type.newtype(:ora_listener) do
  def self.module_name
    'ora_config'
  end

  desc <<-DESC
    This manages the oracle listener process.

    It makes sure the Oracle SQL*Net listener is running.

        ora_listener {'SID':
          ensure  => 'running',
          require => Exec['db_install_instance'],
        }

    The name of the resource *MUST* be the sid for which you want to start the listener,
    unless instance_name is specified.

  DESC

  newproperty(:ensure) do
    desc <<-DESC
      Whether a listener should be running.

      This is a required property without any defaults.
    DESC

    newvalue(:stopped, :event => :service_stopped) do
      provider.stop
    end

    newvalue(:running, :event => :service_started, :invalidate_refreshes => true) do
      provider.start
    end

    aliasvalue(:false, :stopped)
    aliasvalue(:true, :running)

    def retrieve
      provider.status
    end

    def sync
      event = super()

      property = @resource.property(:enable)
      if property
        val = property.retrieve
        property.sync unless property.safe_insync?(val)
      end

      event
    end
  end

  newparam(:instance_name) do
    desc <<-DESC
      The database instance name.

      The instance_name parameter *MUST* be the sid for which you want to start the listener.
    DESC
  end

  newparam(:name) do
    desc <<-DESC
      The sid of the listener to run.
    DESC

    isnamevar
  end
end
