# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:flashback_success) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::AuditProperty

  desc <<-DESC
    Auditing option for the issuance of a successful FLASHBACK operation on that object.

    here is an example on how to use this:

        ora_object_audit { 'SYS.AUD$@test':
          ensure             => 'present',
          ...
          flashback_success  => 'on_access',
          ...
        }

    This enables the auditing of successful flashbacks on the table `AUD$` from user `SYS`. An
    audit record is written on every access.

  DESC

  entry('FBK')
  data_type("Optional[Enum['absent','none','by_access','by_session']]")
end
