# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:password_reuse_time, :parent => Puppet::Parameter::OracleProfileProperty) do
  desc <<-DESC
    Allows you set the password_reuse_time value in a profile.

    The number of days between reuses of a password

    password_reuse_time <value | UNLIMITED | DEFAULT>

    Here is an example on how to use this:

        ora_profile { 'DEFAULT@sid':
          ...
          password_reuse_time       => 'UNLIMITED',
          ...
        }

  DESC

  validate do |value|
    return if /unlimited/i.match?(value.to_s)

    super(value)
  end

  data_type("Optional[Variant[Enum['DEFAULT','UNLIMITED'], Integer]]")
end
