# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:enabled) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Indicates wether or not the job is enabled.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          enabled => 'TRUE',
          ...
        }

    Default value: 'TRUE'

  DESC

  newvalues('TRUE', 'FALSE')
  data_type("Optional[Enum['TRUE', 'FALSE']]")

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('ENABLED')
  end

  on_modify do
    statement = if should.to_s.casecmp('FALSE').zero?
                  "begin dbms_scheduler.disable(name => '#{resource.owner}.#{resource.job_name}', force => true); end;\n/\n"
                else
                  "begin dbms_scheduler.enable(name => '#{resource.owner}.#{resource.job_name}'); end;\n/\n"
                end
    sql statement, { :sid => resource.sid }
  end
end
