# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:end_date) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Specifies a date and time after which the job will not run anymore.
    This property is specified in the European date format, ie 'DD-MM-YYYY HH24:Mi:SS'.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          end_date => '29-04-2018 15:30:00',
          ...
        }

    Puppet doesn't provide a default value.

  DESC

  defaultto ''
  data_type('Optional[String]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('END_DATE')
  end

  on_modify do
    statement = if (resource.end_date != '') || resource.end_date.nil?
                  template('ora_config/ora_scheduler_job/modify_date_attribute.sql.erb', binding)
                else
                  "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'END_DATE'); end;\n/\n"
                end
    sql statement, { :sid => resource.sid }
  end
end
