# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:max_failures) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-DESC
    The maximum number of failures for the job before the job is marked broken.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          max_failures => 5,
          ...
        }

    Puppet doesn't provide a default value.

  DESC

  data_type('Optional[Integer]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('MAX_FAILURES').to_i
  end

  on_modify do
    statement = if (resource.max_failures == '') || resource.max_failures.nil?
                  "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'MAX_FAILURES'); end;\n/\n"
                else
                  template('ora_config/ora_scheduler_job/modify_unquoted_attribute.sql.erb', binding)
                end
    sql statement, { :sid => resource.sid }
  end
end
