# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:repeat_interval) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access

  desc <<-DESC
    Specifies the frequency at which to run the job.
    A PL/SQL function can be used that returns the next date and time to run or
    a calendering syntax expression can be used.

    Here is an example on how to use this:

        ora_scheduler_job{ 'me.my_job@sid':
          ...
          repeat_interval => 'FREQ=HOURLY;INTERVAL=1',
          ...
        }

    Puppet doesn't provide a default value.

  DESC

  # TODO: Find our how and why it returns an empty string
  data_type('Optional[String]')

  to_translate_to_resource do |raw_resource|
    hex_to_raw(raw_resource.column_data('REPEAT_INTERVAL'))
  end

  on_modify do
    statement = if (resource.repeat_interval == '') || resource.repeat_interval.nil?
                  "begin dbms_scheduler.set_attribute_null(name => '#{resource.owner}.#{resource.job_name}', attribute => 'REPEAT_INTERVAL'); end;\n/\n"
                else
                  template('ora_config/ora_scheduler_job/modify_quoted_attribute.sql.erb', binding)
                end
    sql statement, { :sid => resource.sid }
  end
end
