# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:num_datafiles) do
  include Puppet_X::EnterpriseModules::Oracle::DatafileProperty

  desc <<-DESC
    The number of datafiles to use for the tablespace.
    Specify this, instead of the datafile property, when using Oracle Managed Files.
  DESC

  data_type('Optional[Integer]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('NUM_DATAFILES')
  end

  on_modify do
    fail "specified number of datafiles(#{desired_num_datafiles}) is smaller than the current number of datafiles(#{current_num_datafiles})" unless desired_num_datafiles > current_num_datafiles

    command = "alter tablespace #{resource.tablespace_name} add #{file_type}" + (current_num_datafiles...desired_num_datafiles).map { |_i| " size #{resource[:size]} #{autoextend_spec} " }.join(',')
    sql command, :sid => resource.sid
  end
end
