# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:expired) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Password
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly

  desc <<-DESC
    specified if the account is expired.
  DESC

  newvalues(:true, :false)
  data_type('Optional[Boolean]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('ACCOUNT_STATUS').include?('EXPIRED') ? :true : :false
  end

  on_create do
    'password expire' if value.to_s == 'true'
  end

  on_modify do
    if value.to_s == 'true'
      'password expire'
    elsif provider.send(:modified?, resource.parameters.fetch(:password))
      # TODO: Do we want to use this method (in this way)
      ''
    else
      "identified by values '#{current_hashed_password}'"
    end
  end
end
