# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:locked) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly

  desc <<-DESC
    specified if the account is locked.

  DESC

  newvalues(:true, :false)
  data_type('Optional[Boolean]')

  to_translate_to_resource do |raw_resource|
    raw_resource.column_data('ACCOUNT_STATUS').include?('LOCKED') ? :true : :false
  end

  on_modify do
    "account #{state} "
  end

  after_create do
    sql("alter user #{resource.username} account #{state} ", :sid => resource.sid)
  end

  def state
    value.to_s == 'true' ? 'LOCK' : 'UNLOCK'
  end
end
