# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:password) do
  include EasyType
  include EasyType::EncryptedProperty
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Password
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly

  desc <<-DESC
    The user's password.
  DESC

  data_type('Optional[String[1]]')

  #
  # Needed for information
  #
  def sid
    resource.sid
  end

  on_modify do
    "identified by \"#{value}\""
  end

  #
  # In Oracle 19.10 we are not allowed to update the spare4 column, So this code is removed.
  # But this also means we cannot update the SYS passwrod idempotent.
  #
  # after_modify do
  #   if oracle_major_version(sid_from_resource) > 12 && resource.username.upcase == 'SYS'
  #     #
  #     # The regular password update statement, doesn't update the the spare4 field on these
  #     # oracle versions when updateing the SYS password. SO we set it ourselfs to make
  #     # sure it is idempotent. If the user is not SYS, leave everything to Oracle.
  #     #
  #     sql("alter user SYS identified by values '#{password_for_update}'",:sid => resource.sid)
  #   end
  # end

  def insync?(_is)
    return false if is_password_hash.nil?

    create_only_insync?(is_password_hash, should_password_hash)
  end
end
