# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
newproperty(:raw_password) do
  include EasyType
  include Puppet_X::EnterpriseModules::Oracle::Access
  include Puppet_X::EnterpriseModules::Oracle::Password
  include Puppet_X::EnterpriseModules::Oracle::CreateOnly

  desc <<-DESC
      The user's raw password.
  DESC

  data_type('Optional[String[1]]')

  to_translate_to_resource do |_raw_resource|
    nil # Don't expose this property
  end

  def insync?(_is)
    current_hashed_password == should
  end

  def change_to_s(currentvalue, _newvalue)
    if currentvalue == :absent
      'created with specified value'
    else
      'changed to new value'
    end
  end

  def is_to_s(_currentvalue)
    '[old value]'
  end

  def should_to_s(_newvalue)
    '[new value]'
  end

  #
  # Basic implementation for coercing a value to the correct type.
  #
  def coerce(value)
    value
  end

  on_modify do
    "identified by values '#{value}'"
  end
end
