# frozen_string_literal: true

#
# See the file "LICENSE" for the full license governing this code.
#
module Puppet_X
  module EnterpriseModules
    # rubocop:disable Style/Documentation
    module ExtendHash
      # rubocop:enable Style/Documentation
      def included(parent)
        parent.extend(self)
      end

      def with_hash(content, &proc)
        old_content = @__content
        @__content = content # use a double underscore to make sure it doesn't interfere
        yield proc
        @__content = old_content
      end

      def use_hash(content)
        @__content = content # use a double underscore to make sure it doesn't interfere
      end

      def content_if(key, string = default_value_for_key(key))
        "#{string} #{value_for(key)}" if exists?(key)
      end

      def key_if(key, string = default_value_for_key(key))
        string.to_s if exists?(key)
      end

      def exists?(key)
        case value_for(key)
        when nil, '' then false
        else
          true
        end
      end

      # rubocop:disable Lint/ShadowingOuterLocalVariable
      def value_for(key)
        keys = key.split('.')
        keys.inject(@__content) do |location, key|
          location && location[key] ? location[key] : nil
        end
      end
      # rubocop:enable Lint/ShadowingOuterLocalVariable

      private

      def default_value_for_key(key)
        key.split('.').last.tr('_', ' ')
      end
    end
  end
end
